@@ -298,7 +298,8 @@ _osx_codename_map = {4: 'tiger',
                      8: 'mountain lion',
                      9: 'mavericks',
                      10: 'yosemite',
-                     11: 'el capitan'}
+                     11: 'el capitan',
+                     12: 'sierra'}
 def _osx_codename(major, minor):
     if major != 10 or minor not in _osx_codename_map:
         raise OsNotDetected("unrecognized version: %s.%s"%(major, minor))
@@ -642,6 +643,7 @@ OS_FUNTOO='funtoo'
 OS_GENTOO='gentoo'
 OS_LINARO='linaro'
 OS_MINT='mint'
+OS_NEON='neon'
 OS_OPENSUSE='opensuse'
 OS_OPENSUSE13='opensuse'
 OS_OSX='osx'
@@ -662,6 +664,7 @@ OsDetect.register_default(OS_FUNTOO, Funtoo())
 OsDetect.register_default(OS_GENTOO, Gentoo())
 OsDetect.register_default(OS_LINARO, LsbDetect("Linaro"))
 OsDetect.register_default(OS_MINT, LsbDetect("LinuxMint"))
+OsDetect.register_default(OS_NEON, LsbDetect("neon"))
 OsDetect.register_default(OS_OPENSUSE, OpenSuse())
 OsDetect.register_default(OS_OPENSUSE13, OpenSuse(brand_file='/etc/SUSE-brand'))
 OsDetect.register_default(OS_OSX, OSX())
